@@ -63,6 +63,7 @@ typedef struct _PhoshSettings
   gint       drag_handle_offset;
   guint      debounce_handle;
 
+  GtkWidget *scrolled_window;
   GtkWidget *box_settings;
   GtkWidget *quick_settings;
   GtkWidget *scale_brightness;
@@ -137,32 +138,20 @@ phosh_settings_get_property (GObject *object,
 static void
 calc_drag_handle_offset (PhoshSettings *self)
 {
-  gint h;
-  gboolean done = FALSE;
-  const gchar *stack_child;
-  GtkWidget *widget = NULL;
+  int h = 0;
+  int box_height, sw_height;
 
-  stack_child = gtk_stack_get_visible_child_name (GTK_STACK (self->stack_notifications));
-
-  if (self->on_lockscreen) {
-    /* On the lock screen the space below the sliders is fine */
-    widget = self->box_bottom_half;
-  } else if (g_strcmp0 (stack_child, STACK_CHILD_NO_NOTIFICATIONS) == 0) {
-    /* Without notifications the notification box is fine */
-    widget = self->stack_notifications;
-  }
-
-  /* Otherwise assume the whole area shouldn't be draggable */
-  if (!widget)
+  h = gtk_widget_get_allocated_height (GTK_WIDGET (self));
+  /* On the lock screen the whole surface is fine */
+  if (self->on_lockscreen)
     goto out;
 
-  done = gtk_widget_translate_coordinates (widget,
-                                           GTK_WIDGET (self),
-                                           0, 0, NULL, &h);
- out:
-  if (!done)
-    h = gtk_widget_get_allocated_height (GTK_WIDGET (self));
+  box_height = gtk_widget_get_allocated_height (self->box_settings);
+  sw_height = gtk_widget_get_allocated_height (self->scrolled_window);
+  if (box_height > sw_height)
+    h = 0; /* Don't enlarge drag handle if box needs scrolling */
 
+ out:
   if (self->drag_handle_offset == h)
     return;
 
@@ -171,6 +160,15 @@ calc_drag_handle_offset (PhoshSettings *self)
 }
 
 
+static void
+on_size_allocate (PhoshSettings *self)
+{
+  calc_drag_handle_offset (self);
+
+  return;
+}
+
+
 static gboolean
 delayed_update_drag_handle_offset (gpointer data)
 {
@@ -835,8 +833,8 @@ phosh_settings_class_init (PhoshSettingsClass *klass)
 
   /* PhoshSettings:handle-offset:
    *
-   * The offset from the top of the widget where it's safe to start
-   * dragging. Seep hosh_settings_get_drag_drag_handle_offset().
+   * The offset from the bottom of the widget where it's safe to start
+   * dragging. See phosh_settings_get_drag_drag_handle_offset().
    */
   props[PROP_DRAG_HANDLE_OFFSET] =
     g_param_spec_int (
@@ -861,6 +859,7 @@ phosh_settings_class_init (PhoshSettingsClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PhoshSettings, scale_brightness);
   gtk_widget_class_bind_template_child (widget_class, PhoshSettings, scale_torch);
   gtk_widget_class_bind_template_child (widget_class, PhoshSettings, stack_notifications);
+  gtk_widget_class_bind_template_child (widget_class, PhoshSettings, scrolled_window);
 
   gtk_widget_class_bind_template_callback (widget_class, battery_setting_clicked_cb);
   gtk_widget_class_bind_template_callback (widget_class, bt_setting_clicked_cb);
@@ -890,6 +889,8 @@ static void
 phosh_settings_init (PhoshSettings *self)
 {
   gtk_widget_init_template (GTK_WIDGET (self));
+
+  g_signal_connect (self, "size-allocate", G_CALLBACK (on_size_allocate), NULL);
 }
 
 
